<!DOCTYPE html>
<html>
  <head>
    <meta charset='utf-8'>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title>{% block title %}{{ q2templates_default_page_title }}{% endblock %}</title>
    <link rel="stylesheet" href="./q2templateassets/css/bootstrap.min.css"/>
    <link rel="stylesheet" href="./q2templateassets/css/normalize.css"/>
    <link rel="stylesheet" href="./q2templateassets/css/tab-parent.css">
    <script src="./q2templateassets/js/jquery-3.2.0.min.js" charset="utf-8"></script>
    <script src="./q2templateassets/js/parent.js"></script>
  </head>
  <body>
    <div class="container-fluid">
      <div id="q2templatesheader" class="row">
        <div class="col-lg-12">
          <a href="http://qiime2.org/">
            <img src="./q2templateassets/img/qiime2-rect-200.png"
            alt="QIIME 2">
          </a>
        </div>
      </div>
      <div class="row">
        <ul class="nav nav-tabs">
          <li id="{{ tabs[0].url.split('.')[0] }}" class="active"><a href="#">{{ tabs[0].title }}</a></li>
          {% for tab in tabs[1:] %}
          <li id="{{ tab.url.split('.')[0] }}"><a href="#">{{ tab.title }}</a></li>
          {% endfor %}
        </ul>
      </div>
      <iframe id="tab-frame" src="./{{ tabs[0].url }}"></iframe>
    </div>
    <script type="text/javascript">
      if (window.frameElement) {
          document.getElementById('q2templatesheader').remove();
      }
      var frameSrc = {
        {% for tab in tabs %}
        '{{ tab.url.split('.')[0] }}': './{{ tab.url }}',
        {% endfor %}
      };
    </script>
  </body>
</html>
